open-cravat submit

JOBS
STORE
ADMIN
System update available
Version:

Variants
Genome:
Add input file(s) File(s):
Example: OR
Note:
Annotations |
Input File | # Annotators | Genome | Note | Status | Download | Delete
--- | --- | --- | --- | --- | --- | ---

and or

Installed Update available

Updates to your installed modules are available!
Most Downloaded
Newest
Sort by
🡄
There are missing system modules which Open-CRAVAT needs.
Click this button to install them:
System updates in progress...
System configuration file:
Jobs dir:
Modules dir:
Warn if total input file size is larger than: MB
Maximum number of concurrent jobs:
Maximum number of concurrent annotators per job:
Lost connection to the server.
Please launch OpenCRAVAT again.
Uploading input file(s)...
Updating store information...